@@ -11,7 +11,7 @@ from . import defs
 
 
 @dataclasses.dataclass(frozen=True)
-class BoolExpr(metaclass=abc.ABCMeta):
+class BoolExpr(abc.ABC):
     """A boolean expression parsed out of a specification string."""
 
     @abc.abstractmethod
