@@ -49,13 +49,23 @@ EMPTY_SET_SPECS = ["", "0", "none"]
 """The list of exact strings that `parse_stage_ids()` will return an empty list for."""
 
 
+_p_or_expr = pyp.Forward()
+
 _p_ws = pyp.White()[...]
 
 _p_tag = pyp.Char("@").suppress() + pyp.Word(pyp.alphanums + "_-")
 
 _p_keyword = pyp.Word(pyp.alphanums + "_-")
 
-_p_atom = _p_tag | _p_keyword
+_p_bracketed = (
+    pyp.Char("(").suppress()
+    + _p_ws.suppress()
+    + _p_or_expr
+    + _p_ws.suppress()
+    + pyp.Char(")").suppress()
+)
+
+_p_atom = _p_tag | _p_keyword | _p_bracketed
 
 _p_not_atom = pyp.Literal("not").suppress() + _p_ws.suppress() + _p_atom
 
@@ -63,12 +73,12 @@ _p_and_expr = (_p_not_atom | _p_atom) + (
     _p_ws.suppress() + pyp.Literal("and").suppress() + _p_ws.suppress() + (_p_not_atom | _p_atom)
 )[...]
 
-_p_or_expr = (
+_p_or_expr <<= (
     _p_and_expr
     + (_p_ws.suppress() + pyp.Literal("or").suppress() + _p_ws.suppress() + _p_and_expr)[...]
 )
 
-_p_spec = _p_ws.suppress() + _p_or_expr
+_p_spec = _p_ws.suppress() + _p_or_expr + _p_ws.suppress()
 
 
 @_p_tag.set_parse_action
@@ -87,10 +97,10 @@ def _parse_keyword(tokens: pyp.ParseResults) -> expr.KeywordExpr:
     return expr.KeywordExpr(keyword=tokens[0])
 
 
-@_p_atom.set_parse_action
+@_p_atom.set_parse_action  # type: ignore[misc]
 def _parse_atom(tokens: pyp.ParseResults) -> expr.BoolExpr:
     """Parse an atom (a tag or a keyword)."""
-    if len(tokens) != 1 or not isinstance(tokens[0], (expr.TagExpr, expr.KeywordExpr)):
+    if len(tokens) != 1 or not isinstance(tokens[0], (expr.TagExpr, expr.KeywordExpr, expr.OrExpr)):
         raise ParseResultError(tokens)
     return tokens[0]
 
@@ -115,7 +125,7 @@ def _parse_and_expr(tokens: pyp.ParseResults) -> expr.BoolExpr:
     return expr.AndExpr(children=children)
 
 
-@_p_or_expr.set_parse_action  # type: ignore[misc]
+@_p_or_expr.set_parse_action
 def _parse_or_expr(tokens: pyp.ParseResults) -> expr.BoolExpr:
     """Parse a "subexpr [or subexpr...]" subexpression."""
     children: list[expr.BoolExpr] = tokens.as_list()
